import RenderWithoutJS from "@/components/RenderWithoutJS";
import Sidebar from "@/components/Sidebar";
import index from "@/styles/Index.module.sass"
import Lanyard from "@/components/Lanyard"
import { remark } from "remark"
import remarkFrontmatter from "remark-frontmatter"
import { read } from "to-vfile"
import listFiles from "@/lib/listFiles";
import Markdown from 'markdown-to-jsx';
import Link from "@/components/Link";
import Image from "@/components/Image";
import Header from "@/components/Header";
import { useRouter } from 'next/router'

const Post = (props: { post: string, slug: string }) => {
    const router = useRouter()
    console.log(router.asPath)
    let Index = (
        <main id={index.layout}>
            <Sidebar />
            <section id={index.main}>
                <Markdown
                    children={props.post}
                    options={{
                        overrides: {
                            a: ({ ...props }) => <Link href={props.href} title={props.children} withArrow />,
                            img: ({ ...props }) => <Image src={props.src} alt={props.alt} />,
                            p: ({ children, ...props }) => {
                                const ParaComponent = children[0]?.type?.name === 'img' ? 'div' : 'p'
                                return <ParaComponent {...props}>{children}</ParaComponent>
                            },
                            // h1: ({ ...props }) => <Header kind="h1" href={`${router.asPath}#${props.id}`} title={props.children} withArrow />,
                            // h2: ({ ...props }) => <Header kind="h2" href={`${router.asPath}#${props.id}`} title={props.children} withArrow />,
                            // h3: ({ ...props }) => <Header kind="h3" href={`${router.asPath}#${props.id}`} title={props.children} withArrow />,
                            // h4: ({ ...props }) => <Header kind="h4" href={`${router.asPath}#${props.id}`} title={props.children} withArrow />,
                            // h5: ({ ...props }) => <Header kind="h5" href={`${router.asPath}#${props.id}`} title={props.children} withArrow />,
                            // h6: ({ ...props }) => <Header kind="h6" href={`${router.asPath}#${props.id}`} title={props.children} withArrow />,
                            // h6: ({ pass_this, ...props }) => { console.log("h6", { pass_this, props }) },
                        }
                    }}
                />
            </section>
            <Lanyard />
        </main>
    );
    return <RenderWithoutJS children={Index} />
};

export default Post

export async function getStaticProps(context: any) {
    let post = await remark()
        .use(remarkFrontmatter)
        .process(await read(`${listFiles('./src/blog').find(file => file.includes(context.params.slug))}`))
    // .then(r => r.value.)
    return {
        props: {
            post: (post.value as string).replace(/(---)\n*([a-zA-Z0-9\/_:-\s*]*)*/mi, ""),
            slug: context.params.slug
        }
    }
}


export async function getStaticPaths() {
    let path = './src/blog'
    let paths = listFiles(path).map(file => file.replace(path, "/blog").replace(/.mdx?/gmi, ''))
    return {
        paths,
        fallback: true
    }
}